OiRA

Help

1. Příprava
2. Zapojení
3. Vyhledání rizik + Hodnocení rizik
4. Akční plán
5. Zpráva
6. Status 37%

# Stav Commercial guarding, Leicester

## Obecné informace

Použitý nástroj

  Commercial guarding, Leicester

  5 August 2017 by angela.baumeister@company.com

uloženo

  7 June 2018 by hans.mittelmaier@company.com

## Zodpovězené otázky na jeden modul

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 OK
  - 3
  - 2 Pozornost
  - 2 Odloženo
  - 2 Nezodpovězeno

  #### Rizika s vysokou prioritou

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Nezodpovězeno

  1

  1 Pozornost

  1 Odloženo

  - 7 Nezodpovězeno
  - 1
  - 1 Pozornost
  - 1 Odloženo

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More